#[unsafe(no_mangle)]pub extern "C" fn pio_abi_version() -> u32Expand description
The ABI version the library was built with (see PIO_ABI_VERSION). Lets a
consumer detect a stale or incompatible library at load time. Infallible.
#[unsafe(no_mangle)]pub extern "C" fn pio_abi_version() -> u32The ABI version the library was built with (see PIO_ABI_VERSION). Lets a
consumer detect a stale or incompatible library at load time. Infallible.